@@ -3,7 +3,6 @@
 import errno
 import os
 import platform
-import subprocess
 import sys
 import traceback
 
@@ -190,19 +189,13 @@ def build_java_execution(options, daemon):
     if options.log_levels_set and not exists(options.log_levels):
         raise Exception('Log levels file is missing: %s' % options.log_levels)
 
-    with open(os.devnull, 'w') as devnull:
-        try:
-            subprocess.check_call(['java', '-version'], stdout=devnull, stderr=devnull)
-        except (OSError, subprocess.CalledProcessError):
-            raise Exception('Java is not installed')
-
     properties = options.properties.copy()
 
     if exists(options.log_levels):
         properties['log.levels-file'] = options.log_levels
 
     if daemon:
-        properties['log.output-file'] = options.server_log
+        properties['log.path'] = options.server_log
         properties['log.enable-console'] = 'false'
 
     jvm_properties = load_lines(options.jvm_config)
@@ -218,9 +211,13 @@ def build_java_execution(options, daemon):
     system_properties = ['-D%s=%s' % i for i in properties.items()]
     classpath = pathjoin(options.install_path, 'lib', '*')
 
-    command = ['java', '-cp', classpath]
-    command += jvm_properties + options.jvm_options + system_properties
+    java_binary_prefix = ''
+    if os.getenv('JAVA_HOME'):
+        java_binary_prefix = os.getenv('JAVA_HOME') + '/bin/'
+    command = [java_binary_prefix + 'java', '-cp', classpath]
+    command += jvm_properties + system_properties
     command += [main_class]
+    command += options.arguments
 
     if options.verbose:
         print(command)
@@ -228,7 +225,7 @@ def build_java_execution(options, daemon):
 
     env = os.environ.copy()
 
-    # set process name: https://github.com/airlift/procname
+    # set process name: https://github.com/electrum/procname
     process_name = launcher_properties.get('process-name', '')
     if len(process_name) > 0:
         system = platform.system() + '-' + platform.machine()
@@ -361,9 +358,9 @@ def create_parser():
     parser.add_option('--log-levels-file', metavar='FILE', help='Defaults to ETC_DIR/log.properties')
     parser.add_option('--data-dir', metavar='DIR', help='Defaults to INSTALL_PATH')
     parser.add_option('--pid-file', metavar='FILE', help='Defaults to DATA_DIR/var/run/launcher.pid')
+    parser.add_option('--arg', action='append', metavar='ARG', dest='arguments', help='Add a program argument of the Java application')
     parser.add_option('--launcher-log-file', metavar='FILE', help='Defaults to DATA_DIR/var/log/launcher.log (only in daemon mode)')
     parser.add_option('--server-log-file', metavar='FILE', help='Defaults to DATA_DIR/var/log/server.log (only in daemon mode)')
-    parser.add_option('-J', action='append', metavar='OPT', dest='jvm_options', help='Set a JVM option')
     parser.add_option('-D', action='append', metavar='NAME=VALUE', dest='properties', help='Set a Java system property')
     return parser
 
@@ -376,7 +373,7 @@ def parse_properties(parser, args):
         key, value = [i.strip() for i in arg.split('=', 1)]
         if key == 'config':
             parser.error('cannot specify config using -D option (use --config)')
-        if key == 'log.output-file':
+        if key == 'log.path':
             parser.error('cannot specify server log using -D option (use --server-log-file)')
         if key == 'log.levels-file':
             parser.error('cannot specify log levels using -D option (use --log-levels-file)')
@@ -426,7 +423,6 @@ def main():
     o.config_path = realpath(options.config or pathjoin(o.etc_dir, 'config.properties'))
     o.log_levels = realpath(options.log_levels_file or pathjoin(o.etc_dir, 'log.properties'))
     o.log_levels_set = bool(options.log_levels_file)
-    o.jvm_options = options.jvm_options or []
 
     if options.node_config and not exists(o.node_config):
         parser.error('Node config file is missing: %s' % o.node_config)
@@ -447,6 +443,8 @@ def main():
         if k not in o.properties:
             o.properties[k] = v
 
+    o.arguments = options.arguments or []
+
     if o.verbose:
         print_options(o)
 
